/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log.Writer
{
    using System;

    /// <summary>
    /// Base configurator
    /// </summary>
    public abstract class Configurator
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="Configurator"/> class.
        /// </summary>
        protected Configurator()
        {
            this.Logger = new Logger();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Instance of the Logger to return
        /// </summary>
        protected ILogger Logger
        {
            get;
            private set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Adds the specified appender to the appenders' list.
        /// </summary>
        /// <param name="appender">The appender.</param>
        public void AddAppender(IAppender appender)
        {
            this.Logger.Appenders.Add(appender);
        }

        /// <summary>
        /// Removes all the appenders of the specified type.
        /// </summary>
        /// <param name="typeOfAppender">The type of appender.</param>
        public void RemoveAppender(Type typeOfAppender)
        {
            for (int i = 0; i < this.Logger.Appenders.Count; i++)
            {
                if (this.Logger.Appenders[i].GetType() == typeOfAppender)
                {
                    this.Logger.Appenders.RemoveAt(i);
                }
            }
        }

        /// <summary>
        /// Removes the specified appener from the appenders' list.
        /// </summary>
        /// <param name="appender">The appender.</param>
        public void RemoveAppener(IAppender appender)
        {
            this.Logger.Appenders.Remove(appender);
        }

        #endregion Methods
    }
}